# Summary

* [Introduction](README.md)
  * [Introduction to OAuth 2.0 and OpenID Connect](README.md#introduction-to-oauth-20-and-openid-connect)
  * [Introduction to Hydra](README.md#introduction-to-hydra)
  * [OAuth2 Case Study](README.md#oauth-20-case-study)
* [5 Minute Tutorial](tutorial.md)
* [Using Hydra](install.md)
  * [Installing Hydra](install.md#installing-hydra)
  * [Configuring Hydra](install.md#configuring-hydra)
  * [Running Hydra](install.md#running-hydra)
* Understanding Hydra
  * [OAuth2 & OpenID Connect](oauth2.md)
    * [Overview](oauth2.md#overview)
    * [Confirming User Consent: Consent App Flow](oauth2.md#consent-app-flow)
    * [Validating Tokens: OAuth2 Token Introspection](oauth2.md#oauth2-token-introspection)
    * [OAuth2 Scopes](oauth2.md#oauth2-scopes)
  * [JSON Web Keys](jwk.md)
  * [Access Control Policies](access-control.md)
    * [Introduction](access-control.md#introduction-to-access-control-policies)
    * [The Warden](access-control.md#warden)
- [Security Overview](security.md#security-overview)
  - [OAuth 2.0 Security Overview](security.md#oauth-20-security-overview)
    - [Advanced Token Validation (Datastore Security)](security.md#advanced-token-validation-datastore-security)
    - [Access Control Policies](security.md#access-control-policies)
  - [Cryptography](security.md#cryptography)
    - [AES-GCM](security.md#aes-gcm)
    - [RS256](security.md#rs256)
    - [HMAC-SHA256](security.md#hmac-sha256)
    - [BCrypt](security.md#bcrypt)
  - [Access Control](security.md##how-does-access-control-work-with-hydra)
* [Telemetry](telemetry.md)
* How-Tos
  * [Running Hydra in production](how-to/production.md)
  * [Secure the consent app](how-to/consent-app.md)
* [Client Libraries](sdk.md)
  * [Hydra SDK for Go](sdk/go.md)
* [Contribute](contribute.md)
  * [Architecture and Design](contribute.md)
  * [Running Tests](contribute.md)
* [FAQ](faq.md)
  * [How should I run migrations?](faq/migrations.md)
  * [How to deal with mobile apps?](faq/mobile.md)
  * [Why is the Resource Owner Password Credentials grant not supported?](faq/ropc.md)
  * [How can I control SQL connection limits?](faq/sql.md)
  * [Where is the HTTP API Documentation?](faq/http-api.md)
  * [How can I disable HTTPS for testing?](faq/disable-https.md)
  * [How can I import TLS certificates?](faq/https-tls-import.md)
  * [Can I set the log level to warn, error, debug, ...?](faq/log-level.md)
  * [Should I use OAuth2 tokens for authentication?](faq/oauth2-auth.md)
  * [What will happen if an error occurs during an OAuth2 flow?](faq/oauth2-error.md)
  * [Why isn't the redirect url working?](faq/redirect-uri.md)
  * [How do I know if OAuth2 / Hydra is the right choice for me?](faq/when-use.md)
  * [Operational considerations](faq/operations.md)
